# 1 install

```
pip install pyxllib
```

more details: https://www.yuque.com/xlpr/pyxllib/install

# 2 document

document: https://www.yuque.com/xlpr/pyxllib.
Work hard to improve, welcome more assistant partners.
